@@ -1,4 +1,4 @@
-/*  $Id: ident.c 550 2004-06-17 01:27:41Z eagle $
+/*  $Id: ident.c 2429 2006-02-08 20:01:28Z rra $
 **
 **  High-level interface to the ident library.
 **
@@ -35,7 +35,7 @@ IDENT *
 ident_lookup(int fd, int timeout)
 {
     struct sockaddr_in localaddr, remoteaddr;
-    int len;
+    socklen_t len;
 
     len = sizeof(remoteaddr);
     if (getpeername(fd, (struct sockaddr *) &remoteaddr, &len) < 0)
