@@ -1,4 +1,4 @@
-/*  $Id: ident_auth.c 550 2004-06-17 01:27:41Z eagle $
+/*  $Id: ident_auth.c 2430 2006-02-08 21:32:45Z rra $
 **
 **  SASL-based authentication mechanisms for ident.
 **
@@ -49,27 +49,31 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#ifdef HAVE_KERBEROSIV_KRB_H
-# include <kerberosIV/krb.h>
-#else
-# include <krb.h>
+#ifdef HAVE_KRB4
+# ifdef HAVE_KERBEROSIV_KRB_H
+#  include <kerberosIV/krb.h>
+# else
+#  include <krb.h>
+# endif
 #endif
 
 #include "sident.h"
 
 /* Exported definition of requester authentication mechanism */
-static char *krb_requester_start();
 static char *null_requester_start();
-static int krb_requester_auth();
 static int null_requester_auth();
-static void krb_free_state();
 static void null_free_state();
 static char *trivial_requester_start();
 static int trivial_requester_auth();
-static int krb_set_flag();
-static int krb_get_flag();
 static int null_set_flag();
 static int null_get_flag();
+#ifdef HAVE_KRB4
+static char *krb_requester_start();
+static int krb_requester_auth();
+static void krb_free_state();
+#endif
+static int krb_set_flag();
+static int krb_get_flag();
 
 /* GSS-API routines. */
 extern char *gssapi_requester_start();
@@ -78,6 +82,7 @@ extern void gssapi_free_state();
 
 extern char *sfgets();
 
+#ifdef HAVE_KRB4
 struct ident_requester_auth krb_ident_auth = {
     "KERBEROS_V4",
     NULL,
@@ -89,6 +94,7 @@ struct ident_requester_auth krb_ident_auth = {
     krb_set_flag,
     krb_get_flag
 };
+#endif
 
 struct ident_requester_auth gssapi_ident_auth = {
     "GSSAPI",
@@ -126,14 +132,22 @@ struct ident_requester_auth trivial_ident_auth = {
     null_get_flag
 };
 
-
-#define IDENT_METHODS_COUNT 4
+#ifdef HAVE_KRB4
+# define IDENT_METHODS_COUNT 4
+#else
+# define IDENT_METHODS_COUNT 3
+#endif
 
 /* TRIVIAL method must always be the last method. */
 #define IDENT_TRIVIAL_METHOD (IDENT_METHODS_COUNT - 1)
 
 struct ident_requester_auth *auth_methods[IDENT_METHODS_COUNT] = {
-    &krb_ident_auth, &gssapi_ident_auth, &otp_ident_auth, &trivial_ident_auth
+#ifdef HAVE_KRB4
+    &krb_ident_auth,
+#endif
+    &gssapi_ident_auth,
+    &otp_ident_auth,
+    &trivial_ident_auth
 };
 
 /* Start with trivial as the default.  This probably isn't right, but neither
@@ -455,29 +469,6 @@ do_out(char *string, struct ident_auth_client_data *auth_data)
 }
 
 
-/* Private state used by this mechanism */
-struct krb_state {
-    char service[MAX_K_NAME_SZ + 1];
-    int authstepno;
-    des_cblock session;         /* Our session key */
-    des_key_schedule schedule;  /* Schedule for our session key */
-    int32_t challenge;
-    char string[2048];          /* Store built responses */
-    AUTH_DAT kdata;
-};
-
-
-/*
-**  Free the space used by the opaque mechanism state pointer.
-*/
-static void
-krb_free_state(void *state)
-{
-    memset(state, 0, sizeof(struct krb_state));
-    free(state);
-}
-
-
 /*
 **  Handle setting a flag.  Right now, USER-INTERACTION is the only thing
 **  that's supported, so no time has been spent to make this really work
@@ -532,6 +523,34 @@ krb_get_flag(char *flag, char **value)
 }
 
 
+/* Skip all the KERBEROS_V4 implementation unless we're building with v4
+   support. */
+
+#ifdef HAVE_KRB4
+
+/* Private state used by this mechanism */
+struct krb_state {
+    char service[MAX_K_NAME_SZ + 1];
+    int authstepno;
+    des_cblock session;         /* Our session key */
+    des_key_schedule schedule;  /* Schedule for our session key */
+    int32_t challenge;
+    char string[2048];          /* Store built responses */
+    AUTH_DAT kdata;
+};
+
+
+/*
+**  Free the space used by the opaque mechanism state pointer.
+*/
+static void
+krb_free_state(void *state)
+{
+    memset(state, 0, sizeof(struct krb_state));
+    free(state);
+}
+
+
 /*
 **  Start the requester side of a Kerberos v4 authentication exhange.  Returns
 **  the string that should be sent to the remote host.
@@ -719,6 +738,7 @@ krb_requester_auth(struct ident_auth_client_data *auth_data)
     return IDENT_AUTH_FAIL;
 }
 
+#endif /* HAVE_KRB4 */
 
 /*
 **  For the trivial authentication mechanism, we don't have to do anything in
