@@ -1,4 +1,4 @@
-/*  $Id: sident-test.c 554 2004-06-18 06:34:51Z eagle $
+/*  $Id: sident-test.c 2430 2006-02-08 21:32:45Z rra $
 **
 **  This is a daemon suitable for running from tcpserver or inetd that runs
 **  through a sequence of ident calls to the remote host, trying Kerberos v4,
@@ -70,9 +70,11 @@ print_results(const char *tag, IDENT *ident)
             printf(" USER-INTERACTION");
         printf("\r\n");
         printf("        Mechanisms: ");
+#ifdef HAVE_KRB4
         result = ident_query_error("AUTH-MECH", "KERBEROS_V4", ident);
         if (result == IDENT_AUTH_OKAY)
             printf(" KERBEROS_V4");
+#endif
         result = ident_query_error("AUTH-MECH", "GSSAPI", ident);
         if (result == IDENT_AUTH_OKAY)
             printf(" GSSAPI");
@@ -126,6 +128,7 @@ main(int argc, char *argv[])
         }
     }
 
+#ifdef HAVE_KRB4
     /* Testing Kerberos v4. */
     if (interactive) {
         if (ident_set_authtype("KERBEROS_V4", srvtab) != IDENT_AUTH_OKAY)
@@ -148,8 +151,9 @@ main(int argc, char *argv[])
         fprintf(stderr, "ident: cannot set USER-INTERACTION=YES\n");
     ident = ident_lookup(fileno(stdin), 30);
     print_results("KERBEROS_V4, USER-INTERACTION=YES", ident);
+#endif
 
-    /* Testing GSSAPI and Kerberos v4. */
+    /* Testing GSSAPI and Kerberos v5. */
     if (ident_set_authtype("GSSAPI", NULL) != IDENT_AUTH_OKAY)
         fprintf(stderr, "ident: cannot set GSSAPI\n");
     ident = ident_lookup(fileno(stdin), 30);
