@@ -1,4 +1,4 @@
-/*  $Id: tables.c 550 2004-06-17 01:27:41Z eagle $
+/*  $Id: tables.c 2430 2006-02-08 21:32:45Z rra $
 **
 **  String tables used by library routines and made available by sident.h.
 **  The ident_err_txt table must match the enum id_codes.
@@ -27,8 +27,8 @@ const char *ident_err_txt[] = {
     "TIMEOUT"
 };
 
-/* Authentication flags recognized by the KERBEROS_V4 authentication
-   protocol. */
+/* Authentication flags recognized by the KERBEROS_V4 and GSSAPI
+   authentication protocol. */
 const char *ident_krb_auth_flags[] = {
     "USER-INTERACTION"
 };
