@@ -1,4 +1,4 @@
-/*  gssapi.c,v 1.4 2004/06/14 04:45:49 eagle Exp
+/*  $Id: gssapi.c 590 2005-09-23 01:48:18Z eagle $
 **
 **  GSS-API implementation for an S/Ident responder.
 **
@@ -169,7 +169,7 @@ gssapi_ticket_find(struct ident_auth_data *auth_data)
                 return IDENT_SYSTEM_ERROR;
             closedir(tickets);
             if (syslog_flag)
-                syslog(LOG_INFO, "Ticket file %s for %d", filename,
+                syslog(LOG_INFO, "ticket file %s for %d", filename,
                        auth_data->uid);
             return IDENT_AUTH_OKAY;
         } else if (verbose_flag) {
