@@ -1,4 +1,4 @@
-/*  $Id: ident_auth.c 590 2005-09-23 01:48:18Z eagle $
+/*  $Id: ident_auth.c 2430 2006-02-08 21:32:45Z rra $
 **
 **  SASL-based authentication mechanisms for identd.
 **
@@ -51,24 +51,29 @@
 #include <sys/types.h>
 #include <syslog.h>
 
-#ifdef HAVE_KERBEROSIV_KRB_H
-# include <kerberosIV/krb.h>
-#else
-# include <krb.h>
+#ifdef HAVE_KRB4
+# ifdef HAVE_KERBEROSIV_KRB_H
+#  include <kerberosIV/krb.h>
+# else
+#  include <krb.h>
+# endif
 #endif
 
 #include "identd.h"
 
 /* Exported definition of responder authentication mechanism */
-static int krb_responder_start();
 static int null_responder_start();
-static int krb_responder_auth();
 static int null_responder_auth();
-static void krb_free_state();
 static void null_free_state();
 static int trivial_responder_start();
 static int trivial_responder_auth();
 
+#ifdef HAVE_KRB4
+static int krb_responder_start();
+static int krb_responder_auth();
+static void krb_free_state();
+#endif
+
 extern int do_out();
 extern int do_error();
 extern int parse_auth_line();
@@ -79,12 +84,14 @@ extern int gssapi_responder_start();
 extern int gssapi_responder_auth();
 extern void gssapi_free_state();
 
+#ifdef HAVE_KRB4
 struct ident_responder_auth krb_ident_auth = {
     "KERBEROS_V4",
     krb_responder_start,
     krb_responder_auth,
     krb_free_state
 };
+#endif
 
 struct ident_responder_auth gssapi_ident_auth = {
     "GSSAPI",
@@ -107,13 +114,22 @@ struct ident_responder_auth trivial_ident_auth = {
     null_free_state
 };
 
-#define IDENT_METHODS_COUNT 4
+#ifdef HAVE_KRB4
+# define IDENT_METHODS_COUNT 4
+#else
+# define IDENT_METHODS_COUNT 3
+#endif
 
 /* TRIVIAL method must always be the last method */
 #define IDENT_TRIVIAL_METHOD (IDENT_METHODS_COUNT - 1 )
 
 struct ident_responder_auth *auth_methods[IDENT_METHODS_COUNT] = {
-    &krb_ident_auth, &gssapi_ident_auth, &otp_ident_auth, &trivial_ident_auth
+#ifdef HAVE_KRB4
+    &krb_ident_auth,
+#endif
+    &gssapi_ident_auth,
+    &otp_ident_auth,
+    &trivial_ident_auth
 };
 
 /*
@@ -274,6 +290,11 @@ ident_writebase64(char *input, char *output, int len)
     strcpy(outptr, buf);
 }
 
+/* Skip all the KERBEROS_V4 implementation unless we're building with v4
+   support. */
+
+#ifdef HAVE_KRB4
+
 /* Private state used by this mechanism */
 struct krb_state {
     char service[MAX_K_NAME_SZ + 1];
@@ -682,6 +703,7 @@ krb_responder_auth(struct ident_auth_data *auth_data)
     return IDENT_AUTH_FAIL;
 }
 
+#endif /* HAVE_KRB4 */
 
 /*
 **  Start traditional ident authentication.  Does nothing except retrieve the
