@@ -1,4 +1,4 @@
-/*  $Id: identd.c 590 2005-09-23 01:48:18Z eagle $
+/*  $Id: identd.c 2429 2006-02-08 20:01:28Z rra $
 **
 **  A TCP/IP S/Ident protocol server (main routines).
 **
@@ -75,7 +75,7 @@ gethost(struct in_addr *addr)
 int
 main(int argc, char *argv[])
 {
-    int len;
+    socklen_t len;
     struct sockaddr_in sin;
     struct in_addr laddr, faddr;
     int option;
